==> haskell-persistent-template-2.5.1.6-19-i686.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-template
version: 2.5.1.6
id: persistent-template-2.5.1.6-1fNo3cuT1EYLFj6bbp9nFL
key: persistent-template-2.5.1.6-1fNo3cuT1EYLFj6bbp9nFL
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Persist.TH
abi: 8c1748281850031619c838fe3d485d31
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-template-2.5.1.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-template-2.5.1.6
data-dir: /usr/share/i386-linux-ghc-8.0.1/persistent-template-2.5.1.6
hs-libraries: HSpersistent-template-2.5.1.6-1fNo3cuT1EYLFj6bbp9nFL
depends:
    aeson-1.0.2.1-APwMyQyIboIL2RMSmpN5uA
    aeson-compat-0.3.6-B48jh7w97CS9Xzj1ogdh1 base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1 ghc-prim-0.5.0.0
    http-api-data-0.3.3-gWqkJcSgPqBdIr3KRC9Tk
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.20.1-32CBvhp6gFq5BE9pZkL20q
    path-pieces-0.2.1-EkkcipvGNTB6jNvz5dfdoN
    persistent-2.6-GvuThmb8AvVA76cBwelYX7
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
haddock-interfaces: /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock
haddock-html: /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-template-2.5.1.6-21-i686.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-template
version: 2.5.1.6
id: persistent-template-2.5.1.6-BVZV6Y3UP10IaKUYtzkiqw
key: persistent-template-2.5.1.6-BVZV6Y3UP10IaKUYtzkiqw
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Persist.TH
abi: 3eb4ce11b92d31f1d335c625339b3181
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-template-2.5.1.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/persistent-template-2.5.1.6
data-dir: /usr/share/i386-linux-ghc-8.0.1/persistent-template-2.5.1.6
hs-libraries: HSpersistent-template-2.5.1.6-BVZV6Y3UP10IaKUYtzkiqw
depends:
    aeson-1.0.2.1-5XK8RqnOp1ECyMyMhI5r8M
    aeson-compat-0.3.6-DrMAu7T5S7F321Gq033Ffo base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1 ghc-prim-0.5.0.0
    http-api-data-0.3.3-8AdTBIOisZBIby08WtvS1h
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.20.1-F3BuyfbCJnyKp4tynYJDTL
    path-pieces-0.2.1-EkkcipvGNTB6jNvz5dfdoN
    persistent-2.6-CmglJvAwYgZ1NxEV70EHwD
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.7.2-fKwgRekRaR5O5PqcoNK7l
haddock-interfaces: /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock
haddock-html: /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
